gw2buildutil 0.2.

Python 3 library for working with [Guild Wars 2](https://www.guildwars2.com/en/)
builds.

http://ikn.org.uk/lib/gw2buildutil

# License

Distributed under the terms of the
[BSD 3-Clause license](https://opensource.org/licenses/BSD-3-Clause).

# Installation

Build dependencies:
- [Setuptools](https://setuptools.readthedocs.io/en/latest/)
- [Bash](https://www.gnu.org/software/bash/)

Run `make`, `make install`.  The usual `DESTDIR`, etc. arguments to `make` are
supported.

# Dependencies

- [Python 3](http://www.python.org) (>= 3.7)
